@@ -7,7 +7,12 @@ import sys
 
 import py
 import pytest
-from pathlib2 import Path
+
+if sys.version_info[:2] >= (3, 4):
+    from pathlib import Path
+else:
+    from pathlib2 import Path
+
 from six.moves.urllib.parse import urljoin
 from six.moves.urllib.request import pathname2url
 
@@ -73,7 +78,7 @@ def test_provision_basepython_global_only(newconfig, next_tox_major):
 
 
 def test_provision_basepython_local(newconfig, next_tox_major):
-    """however adhere to basepython when explicilty set"""
+    """however adhere to basepython when explicitly set"""
     with pytest.raises(MissingRequirement) as context:
         newconfig(
             [],
@@ -126,7 +131,9 @@ def test_provision_cli_args_ignore(cmd, initproj, monkeypatch, plugin):
         return result
 
     monkeypatch.setattr(
-        tox.config.ParseIni, "ensure_requires_satisfied", ensure_requires_satisfied,
+        tox.config.ParseIni,
+        "ensure_requires_satisfied",
+        ensure_requires_satisfied,
     )
     prev_get_venv = tox.session.Session.getvenv
 
@@ -203,7 +210,11 @@ def magic_non_canonical_wheel(wheel, tmp_path_factory):
 
 
 def test_provision_non_canonical_dep(
-    cmd, initproj, monkeypatch, tox_wheel, magic_non_canonical_wheel,
+    cmd,
+    initproj,
+    monkeypatch,
+    tox_wheel,
+    magic_non_canonical_wheel,
 ):
     initproj(
         "w-0.1",
