@@ -6,7 +6,10 @@ import subprocess
 import sys
 import tempfile
 
-import pathlib2
+if sys.version_info[:2] >= (3, 4):
+    import pathlib
+else:
+    import pathlib2 as pathlib
 import py
 import pytest
 
@@ -142,7 +145,8 @@ def test_envdir_equals_toxini_errors_out(cmd, initproj):
     result = cmd()
     assert result.outlines[1] == "ERROR: ConfigError: envdir must not equal toxinidir"
     assert re.match(
-        r"ERROR: venv \'python\' in .* would delete project", result.outlines[0],
+        r"ERROR: venv \'python\' in .* would delete project",
+        result.outlines[0],
     ), result.outlines[0]
     result.assert_fail()
 
@@ -461,7 +465,7 @@ def test_no_setup_py_exits_but_pyproject_toml_does(cmd, initproj):
         },
     )
     os.remove("setup.py")
-    pathlib2.Path("pyproject.toml").touch()
+    pathlib.Path("pyproject.toml").touch()
     result = cmd()
     result.assert_fail()
     assert any(
@@ -524,7 +528,9 @@ def test_toxuone_env(cmd, example123):
     result = cmd()
     result.assert_success()
     assert re.match(
-        r".*generated\W+xml\W+file.*junit-python\.xml" r".*\W+1\W+passed.*", result.out, re.DOTALL,
+        r".*generated\W+xml\W+file.*junit-python\.xml" r".*\W+1\W+passed.*",
+        result.out,
+        re.DOTALL,
     )
     result = cmd("-epython")
     result.assert_success()
@@ -675,7 +681,9 @@ def test_test_usedevelop(cmd, initproj, src_root, skipsdist):
     result = cmd("-v")
     result.assert_success()
     assert re.match(
-        r".*generated\W+xml\W+file.*junit-python\.xml" r".*\W+1\W+passed.*", result.out, re.DOTALL,
+        r".*generated\W+xml\W+file.*junit-python\.xml" r".*\W+1\W+passed.*",
+        result.out,
+        re.DOTALL,
     )
     assert "sdist-make" not in result.out
     result = cmd("-epython")
@@ -706,7 +714,9 @@ def test_test_usedevelop(cmd, initproj, src_root, skipsdist):
     result.assert_fail()
     assert "develop-inst-noop" in result.out
     assert re.match(
-        r".*\W+1\W+failed.*" r"summary.*" r"python:\W+commands\W+failed.*", result.out, re.DOTALL,
+        r".*\W+1\W+failed.*" r"summary.*" r"python:\W+commands\W+failed.*",
+        result.out,
+        re.DOTALL,
     )
 
     # test develop is called if setup.py changes
@@ -903,7 +913,8 @@ def test_devenv(initproj, cmd, has_config):
             commands = python -c "exit(1)"
             """
     initproj(
-        "example123", filedefs=filedefs,
+        "example123",
+        filedefs=filedefs,
     )
     result = cmd("--devenv", "venv")
     result.assert_success()
@@ -1072,12 +1083,19 @@ def test_envtmpdir(initproj, cmd):
 
 
 def test_missing_env_fails(initproj, cmd):
-    initproj("foo", filedefs={"tox.ini": "[testenv:foo]\ncommands={env:VAR}"})
+    ini = """
+    [testenv:foo]
+    install_command={env:FOO}
+    commands={env:VAR}
+    """
+    initproj("foo", filedefs={"tox.ini": ini})
     result = cmd()
     result.assert_fail()
     assert result.out.endswith(
-        "foo: unresolvable substitution(s): 'VAR'."
-        " Environment variables are missing or defined recursively.\n",
+        "foo: unresolvable substitution(s):\n"
+        "    commands: 'VAR'\n"
+        "    install_command: 'FOO'\n"
+        "Environment variables are missing or defined recursively.\n",
     )
 
 
@@ -1108,8 +1126,8 @@ def test_tox_cmdline_args(initproj):
 
 @pytest.mark.parametrize("exit_code", [0, 6])
 def test_exit_code(initproj, cmd, exit_code, mocker):
-    """ Check for correct InvocationError, with exit code,
-        except for zero exit code """
+    """Check for correct InvocationError, with exit code,
+    except for zero exit code"""
     import tox.exception
 
     mocker.spy(tox.exception, "exit_code_str")
